@@ -2,11 +2,12 @@
 #
 #  Net::Server - bdpO - Extensible Perl internet server
 #
-#  $Id: Server.pm,v 1.43 2002/06/20 20:01:59 rhandom Exp $
+#  $Id: Server.pm,v 1.52 2003/11/06 19:56:48 hookbot Exp $
 #
-#  Copyright (C) 2001, Paul T Seamons
-#                      paul at seamons.com
-#                      http://seamons.com/
+#  Copyright (C) 2001-2003
+#    Paul T Seamons (paul at seamons.com)
+#    http://seamons.com/
+#    Rob Brown (bbb at cpan.org)
 #
 #  This package may be distributed under the terms of either the
 #  GNU General Public License
@@ -34,7 +35,7 @@ use Net::Server::Daemonize qw(check_pid_file create_pid_file
                               safe_fork
                               );
 
-$VERSION = '0.84';
+$VERSION = '0.86';
 
 ### program flow
 sub run {
@@ -134,6 +135,7 @@ sub configure {
   my $self = shift;
   my $prop = $self->{server};
   my $template = undef;
+  local @_ = @_; # fix some issues under old perls on alpha systems
 
   ### allow for a template to be passed
   if( $_[0] && ref($_[0]) ){
@@ -200,12 +202,13 @@ sub post_configure {
     $prop->{syslog_facility} = ($fac =~ /^((\w+)($|\|))*/)
       ? $1 : 'daemon';
 
-    require "Sys/Syslog.pm";
+    require Sys::Syslog;
     Sys::Syslog::setlogsock($prop->{syslog_logsock}) || die "Syslog err [$!]";
-    Sys::Syslog::openlog(   $prop->{syslog_ident},
-                            $prop->{syslog_logopt},
-                            $prop->{syslog_facility},
-                            ) || die "Couldn't open syslog [$!]";
+    if( ! Sys::Syslog::openlog($prop->{syslog_ident},
+                               $prop->{syslog_logopt},
+                               $prop->{syslog_facility}) ){
+      die "Couldn't open syslog [$!]" if $prop->{syslog_logopt} ne 'ndelay';
+    }
 
   ### open a logging file
   }elsif( $prop->{log_file} ){
@@ -439,7 +442,7 @@ sub post_bind {
     }
     if( $prop->{chown_log_file} ){
       delete $prop->{chown_log_file};
-      push @chown_files, $prop->{log_file};      
+      push @chown_files, $prop->{log_file};
     }
     my $uid = $prop->{user};
     my $gid = (split(/\ /,$prop->{group}))[0];
@@ -474,8 +477,10 @@ sub post_bind {
     }
   };
   if( $@ ){
-    if( $< == 0 || $> == 0 ){
+    if( $> == 0 ){
       $self->fatal( $@ );
+    } elsif( $< == 0){
+      $self->log(2,"NOTICE: Effective UID changed, but Real UID is 0: $@");
     }else{
       $self->log(2,$@);
     }
@@ -750,7 +755,7 @@ sub process_request {
   ### handle udp packets (udp echo server)
   if( $prop->{udp_true} ){
     if( $prop->{udp_data} =~ /dump/ ){
-      require "Data/Dumper.pm";
+      require Data::Dumper;
       $prop->{client}->send( Data::Dumper::Dumper( $self ) , 0);
     }else{
       $prop->{client}->send("You said \"$prop->{udp_data}\"", 0 );
@@ -781,7 +786,7 @@ sub process_request {
       }
 
       if( /dump/ ){
-        require "Data/Dumper.pm";
+        require Data::Dumper;
         print Data::Dumper::Dumper( $self );
       }
 
@@ -1156,7 +1161,7 @@ sub process_conf {
   my @args = ();
 
   if( ! $self->{server}->{conf_file_args} ){
-    $file = ($file =~ m|^([\w\.\-/]+)$|)
+    $file = ($file =~ m|^([\w\.\-\/\\\:]+)$|)
       ? $1 : $self->fatal("Unsecure filename \"$file\"");
 
     if( not open(_CONF,"<$file") ){
@@ -2057,14 +2062,15 @@ Paul T. Seamons <paul at seamons.com>
 
 =head1 THANKS
 
-Thanks to Rob Brown <rbrown at about-inc.com> for help with
+Thanks to Rob Brown (bbb at cpan.org) for help with
 miscellaneous concepts such as tracking down the
 serialized select via flock ala Apache and the reference
 to IO::Select making multiport servers possible.  And for
 researching into allowing sockets to remain open upon
 exec (making HUP possible).
+Rob Brown is also the maintainer for Net::Server.
 
-Thanks to Jonathan J. Miner <miner@doit.wisc.edu> for
+Thanks to Jonathan J. Miner <miner at doit.wisc.edu> for
 patching a blatant problem in the reverse lookups.
 
 Thanks to Bennett Todd <bet at rahul.net> for
